/*
 * @author Walther Neuper, member of the ISAC-team, 
 * Copyright (c) 2004 by Walther Neuper 
 * created Oct 7, 2004, 5:51:50 PM
 * Institute for Softwaretechnology, Graz University of Technology, Austria.
 * 
 * Use is subject to license terms.
 */
package isac.util.formulae;

import junit.framework.TestCase;

/**
 * @author Walther Neuper Oct 7, 2004, 5:51:50 PM
 * @version 1.0
 */
public class TestCalcHead extends TestCase {

	private CalcHead ch = new CalcHead();

	protected void setUp() throws Exception {
		//the complete CalcHead for mini-subpbl
	    ch.setCalcHeadStatus("correct");
		//----------------------the headline
	    Formula f = new Formula();
	    f.setText("solve (x + 1 = 2, x)");
		ch.setHeadLine(f);

		//----------------------the model
		Model m = new Model();
		ModelItemList its;
		ModelItem it1 = new ModelItem(), it2 = new ModelItem();

		it1.setText("equality (x+1=2)");
		it1.setItemStatus("correct");
		it2.setText("solveFor x");
		it2.setItemStatus("correct");
		its = new ModelItemList();
		its.addItem(it1);
		its.addItem(it2);
		m.setGiven(its);//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

		it1.setText("matches (?a = ?b) (x+1=2)");
		it1.setItemStatus("correct");
		its = new ModelItemList();
		its.addItem(it1);
		m.setWhere(its);//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

		it1.setText("solutions L");
		it1.setItemStatus("correct");
		its = new ModelItemList();
		its.addItem(it1);
		m.setFind(its);//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
		ch.setModel(m);

		//----------------------
		ch.setBelongsTo("Pbl");

		//----------------------the specification
		Specification s = new Specification();
		CalcHeadSimpleID id;

		id = new CalcHeadSimpleID();
		id.setID("Test.thy");
		s.setTheory(id);

		KEStoreID idl = new ProblemID();
		idl.addString("sqroot-test");
		idl.addString("univariate");
		idl.addString("equation");
		idl.addString("test");
		s.setProblem(idl);

		idl = new KEStoreID();
		idl.addString("Test");
		idl.addString("squ-equ-test-subpbl1");
		s.setMethod(idl);
		
		ch.setSpecification(s);
	}

	public void testUsesProblem() {
		System.out.println("---BEGIN isac.util.formulae.TestCalcHead");		
		System.out.println("---BEGIN TestCalcHead#testUsesProblem");		

		ProblemID p = new ProblemID("[sqroot-test,univariate,equation,test]");
		assertTrue("pbl belongs to class defined by itself",ch.usesProblem(p));
		
		p = new ProblemID("[equation,test]");
		assertFalse("usual case: not member of class",ch.usesProblem(p));
		assertTrue("usual case: member of class",ch.usesProblemClass(p));
		
		p = new ProblemID("[]");
		assertTrue("[] is superClass for all pbls",ch.usesProblemClass(p));

		System.out.println("---END TestCalcHead#testUsesProblem");		
	}

	public void testToSMLstring() {
		System.out.println("---BEGIN TestCalcHead#testToSMLstring");		
/*WN050617
 *   modifyCalcHead 1 (([],Pbl),(*the position from refFormula*)
		  "solve (x+1=2, x)",(*the headline*)
		  [Given ["equality (x+1=2)", "solveFor x"],
		   Find ["solutions L"](*,Relate []*)],
		  Pbl, 
		  ("Test.thy", 
		   ["sqroot-test","univariate","equation","test"],
		   ["Test","squ-equ-test-subpbl1"]));
 */
		//System.out.print(".CalcHead.toSMLstring="+ch.toSMLString());

		System.out.println("---END TestCalcHead#testToSMLstring");		
		System.out.println("---END isac.util.formulae.TestCalcHead");		
	}

}