/****************************************************************** 
 * Copyright (c) 2003, Mario Hochreiter, Student of 
 * Software Engineering at FH-Hagenberg, Austria. 
 * Project member of the isac team at the Institute for 
 * Software-Technologie, Graz University of Technology, Austria. 
 * 
 * Use is subject to license terms.
 ******************************************************************/

package isac.gui.calcheadviews;

import isac.gui.util.SpringUtilities;
import isac.util.formulae.CalcHead;

import java.util.Locale;

import javax.swing.*;

import org.apache.log4j.Logger;

/**
 * @author Mario Hochreiter
 * @version 1.0
 *  
 */
public class FullCalcHeadView extends CalcHeadView {
    static Logger logger_ = Logger.getLogger(FullCalcHeadView.class.getName());

    public FullCalcHeadView(Locale locale, CalcHead ch) {
        super(locale);
        this.init();
        this.fillTextFieldsFromCalcHead(ch);
    }

    private void init() {
        this.buildTextFields();
        this.buildLabels();
        this.layoutComponents();
    }

    protected void layoutComponents() {
        this.setLayout(new SpringLayout());
        this.add(label_given_);
        this.add(txt_given_);
        this.add(label_where_);
        this.add(txt_where_);
        this.add(label_find_);
        this.add(txt_find_);
        this.add(label_relate_);
        this.add(txt_relate_);
        this.add(label_problem_);
        this.add(txt_problem_);
        this.add(label_method_);
        this.add(txt_method_);
        this.add(label_theory_);
        this.add(txt_theory_);
        SpringUtilities.makeCompactGrid(this, 7, 2, //rows, cols
                5, 5, //initialX, initialY
                5, 5);//xPad, yPad
    }

    /** Creates the text input fields for this panel. */
    protected void buildTextFields() {
        txt_given_ = new JTextPane();
        txt_given_.setBorder(BorderFactory.createEtchedBorder());
        txt_where_ = new JTextPane();
        txt_where_.setEditable(false);
        txt_where_.setBorder(BorderFactory.createEtchedBorder());
        txt_find_ = new JTextPane();
        txt_find_.setBorder(BorderFactory.createEtchedBorder());
        txt_theory_ = new JTextPane();
        txt_theory_.setBorder(BorderFactory.createEtchedBorder());
        txt_method_ = new JTextPane();
        txt_method_.setBorder(BorderFactory.createEtchedBorder());
        txt_problem_ = new JTextPane();
        txt_problem_.setBorder(BorderFactory.createEtchedBorder());
        txt_relate_ = new JTextPane();
        txt_relate_.setBorder(BorderFactory.createEtchedBorder());
    }

    /**
     * @param ch
     *            CalcHead from wich the data is read to fill out the text
     *            fields
     */
    public void fillCalcHeadFromTextFields(CalcHead ch) {
        //methods from abstract superclass CalcHeadView
        this.insertSpecificationFromTextFieldsInCalcHead(ch);
        this.insertTxtGivenInCalcHead(ch);
        this.insertTxtWhereInCalcHead(ch);
        this.insertTxtFindInCalcHead(ch);
        this.insertTxtRelateInCalcHead(ch);

        ch.setCalcHeadStatus(CalcHead.MODEL_ITEM_CORRECT);//WN050624 drop !!!
    }

    /**
     * @param ch
     *            CalcHead from wich the data is read to fill out the text
     *            fields
     */
    public void fillTextFieldsFromCalcHead(CalcHead ch) {
        logger_.info(ch.getGiven() + " " + ch.getFind());

        clearTextFields();
        boolean correct;
        correct = this.checkAndFormatCalcHeadItems(ch.getModel().getGiven()
                .getItems().iterator(), txt_given_);
        this.colorizeLabel(correct, label_given_);
        correct = this.checkAndFormatCalcHeadItems(ch.getModel().getFind()
                .getItems().iterator(), txt_find_);
        this.colorizeLabel(correct, label_find_);
        correct = this.checkAndFormatCalcHeadItems(ch.getModel().getWhere()
                .getItems().iterator(), txt_where_);
        this.colorizeLabel(correct, label_where_);
        correct = this.checkAndFormatCalcHeadItems(ch.getModel().getRelate()
                .getItems().iterator(), txt_relate_);
        this.colorizeLabel(correct, label_relate_);

        // the items below have no status -> no colorization needed
        this.checkAndFormatCalcHeadItems(ch.getSpecification().getMethod()
                .getID().iterator(), txt_method_);
        this.checkAndFormatCalcHeadItems(ch.getSpecification().getProblem()
                .getID().iterator(), txt_problem_);
        txt_theory_.setText(ch.getSpecification().getTheory().getID());
    }

    /** Creates the labels for this panel. */
    protected void buildLabels() {
        label_given_ = new JLabel(res_bundle_.getString("given"));
        label_where_ = new JLabel(res_bundle_.getString("where"));
        label_find_ = new JLabel(res_bundle_.getString("find"));
        label_theory_ = new JLabel(res_bundle_.getString("theory"));
        label_method_ = new JLabel(res_bundle_.getString("method"));
        label_problem_ = new JLabel(res_bundle_.getString("problem"));
        label_relate_ = new JLabel(res_bundle_.getString("relate"));
    }

}